@@ -18,7 +18,7 @@ CUSTOM_IMAGE_RECOGNITION = "custom-recognition"
 CUSTOM_OBJECT_DETECTION = "custom-object-detection"
 PHOTO_SIMILARITY = "photo-similarity"
 PRODUCT_SIMILARITY = "product-similarity"
-PRODUCT_SIMILARITY_TAGS = "product-similarity-tags"
+FASHION_SIMILARITY = "fashion-similarity"
 GENERIC_TAGGING = "generic-tagging"
 FASHION_TAGGING = "fashion-tagging"
 VISUAL_SEARCH = "visual-search"
